==> nsafirstlibrary-1.0.0.tgz: package/resources/availability.js <==
'use strict';

// Include global module
var globals = require('../global')

//Declare token
var token;

//Declare url
var url;

module.exports = {

  //List availability method request
  getAvailability: function (path, host, currentObject, success) {

    // Assign Complete url
    url = host + path;

    //Define Bearer authorization
    token = 'Bearer ' + currentObject.state.token;

    //Set request
    globals.https.get(url)
      .set('Content-Type', 'application/json')
      .set('Authorization', token)
      .set('latitude', currentObject.state.latitude)
      .set('longitude', currentObject.state.longitude)
      .end(function (error, response) {
        if (response)
          success(response.body, JSON.parse(response.statusCode), currentObject);
        else
          success(globals.errBody, globals.errStatusCode, currentObject);
      })

  },

  getAvailabilityWithHash: function (path, host, currentObject, success) {

    // Assign Complete url
    url = host + path;

    //Define Bearer authorization
    token = 'Bearer ' + currentObject.state.token;

    //Set request
    globals.https.put(url)
      .set('Content-Type', 'application/json')
      .set('Authorization', token)
      .set('latitude', currentObject.state.latitude)
      .set('longitude', currentObject.state.longitude)
      .send(JSON.stringify(currentObject.state.requestData))
      .end(function (error, response) {
        if (response)
          success(response.body, JSON.parse(response.statusCode), currentObject);
        else
          success(globals.errBody, globals.errStatusCode, currentObject);
      })

  },

  //List availability method request
  getAvailabilityDefaults: function (path, host, currentObject, success) {

    // Assign Complete url
    url = host + path;

    //Define Bearer authorization
    token = 'Bearer ' + currentObject.state.token;

    //Set request
    globals.https.get(url)
      .set('Content-Type', 'application/json')
      .set('Authorization', token)
      .set('latitude', currentObject.state.latitude)
      .set('longitude', currentObject.state.longitude)
      .end(function (error, response) {
        if (response)
          success(response.body, JSON.parse(response.statusCode), currentObject);
        else
          success(globals.errBody, globals.errStatusCode, currentObject);
      })

  },


  //Update availability request
  postAvailability: function (path, host, currentObject, success) {

    //Define bearer authorization
    token = 'Bearer ' + currentObject.state.token

    // Assign Complete url
    url = host + path;

    //Define Bearer authorization
    token = 'Bearer ' + currentObject.state.token;

    //Set request
    globals.https.post(url)
      .set('Content-Type', 'application/json')
      .set('Authorization', token)
      .set('latitude', currentObject.state.latitude)
      .set('longitude', currentObject.state.longitude)
      .send(JSON.stringify(currentObject.state.requestData))
      .end(function (error, response) {
        if (response)
          success(response.body, JSON.parse(response.statusCode), currentObject);
        else
          success(globals.errBody, globals.errStatusCode, currentObject);
      })

  },

  //Update availability by date request
  putAvailabilityByDate: function (path, host, currentObject, success) {

    // Assign Complete url
    url = host + path;

    //Define Bearer authorization
    token = 'Bearer ' + currentObject.state.token;

    //Set request
    globals.https.put(url)
      .set('Content-Type', 'application/json')
      .set('Authorization', token)
      .set('latitude', currentObject.state.latitude)
      .set('longitude', currentObject.state.longitude)
      .send(JSON.stringify(currentObject.state.requestData))
      .end(function (error, response) {
        if (response)
          success(response.body, JSON.parse(response.statusCode), currentObject);
        else
          success(globals.errBody, globals.errStatusCode, currentObject);
      })

  },

  //Remove availability by date request
  deleteAvailabilityByDate: function (path, host, currentObject, success) {

   // Assign Complete url
    url = host + path;

    //Define Bearer authorization
    token = 'Bearer ' + currentObject.state.token;

    //Set request
    globals.https.del(url)
      .set('Content-Type', 'application/json')
      .set('Authorization', token)
      .set('latitude', currentObject.state.latitude)
      .set('longitude', currentObject.state.longitude)
      .end(function (error, response) {
        if (response)
          success(response.body, JSON.parse(response.statusCode), currentObject);
        else
          success(globals.errBody, globals.errStatusCode, currentObject);
      })

  },

  //Update availability defaults request
  postAvailabilityDefaults: function (path, host, currentObject, success) {

    // Assign Complete url
    url = host + path;

    //Define Bearer authorization
    token = 'Bearer ' + currentObject.state.token;

    //Set request
    globals.https.post(url)
      .set('Content-Type', 'application/json')
      .set('Authorization', token)
      .set('latitude', currentObject.state.latitude)
      .set('longitude', currentObject.state.longitude)
      .send(JSON.stringify(currentObject.state.requestData))
      .end(function (error, response) {
        if (response)
          success(response.body, JSON.parse(response.statusCode), currentObject);
        else
          success(globals.errBody, globals.errStatusCode, currentObject);
      })

  }

}

==> nsafirstlibrary-2.0.0.tgz: package/resources/availability.js <==
'use strict';

// Include global module
var globals = require('../global')

//Declare url
var url;

module.exports = {

  //List availability method request
  getAvailability: function (path, host, token, currentObject, success) {

    // Assign Complete url
    url = host + path;

    //Define Bearer authorization
    token = 'Bearer ' + token;

    //Set request
    globals.https.get(url)
      .set('Content-Type', 'application/json')
      .set('Authorization', token)
      .set('latitude', currentObject.state.latitude)
      .set('longitude', currentObject.state.longitude)
      .end(function (error, response) {
        if (response)
          success(response.body, JSON.parse(response.statusCode), currentObject);
        else
          success(globals.errBody, globals.errStatusCode, currentObject);
      })

  },

  getAvailabilityWithHash: function (path, host, token, currentObject, success) {

    // Assign Complete url
    url = host + path;

    //Define Bearer authorization
    token = 'Bearer ' + token;

    //Set request
    globals.https.put(url)
      .set('Content-Type', 'application/json')
      .set('Authorization', token)
      .set('latitude', currentObject.state.latitude)
      .set('longitude', currentObject.state.longitude)
      .send(JSON.stringify(currentObject.state.requestData))
      .end(function (error, response) {
        if (response)
          success(response.body, JSON.parse(response.statusCode), currentObject);
        else
          success(globals.errBody, globals.errStatusCode, currentObject);
      })

  },

  //List availability method request
  getAvailabilityDefaults: function (path, host, token, currentObject, success) {

    // Assign Complete url
    url = host + path;

    //Define Bearer authorization
    token = 'Bearer ' + token;

    //Set request
    globals.https.get(url)
      .set('Content-Type', 'application/json')
      .set('Authorization', token)
      .set('latitude', currentObject.state.latitude)
      .set('longitude', currentObject.state.longitude)
      .end(function (error, response) {
        if (response)
          success(response.body, JSON.parse(response.statusCode), currentObject);
        else
          success(globals.errBody, globals.errStatusCode, currentObject);
      })

  },


  //Update availability request
  postAvailability: function (path, host, token, currentObject, success) {

    // Assign Complete url
    url = host + path;

    //Define Bearer authorization
    token = 'Bearer ' + token;

    //Set request
    globals.https.post(url)
      .set('Content-Type', 'application/json')
      .set('Authorization', token)
      .set('latitude', currentObject.state.latitude)
      .set('longitude', currentObject.state.longitude)
      .send(JSON.stringify(currentObject.state.requestData))
      .end(function (error, response) {
        if (response)
          success(response.body, JSON.parse(response.statusCode), currentObject);
        else
          success(globals.errBody, globals.errStatusCode, currentObject);
      })

  },

  //Update availability by date request
  putAvailabilityByDate: function (path, host, token, currentObject, success) {

    // Assign Complete url
    url = host + path;

    //Define Bearer authorization
    token = 'Bearer ' + token;

    //Set request
    globals.https.put(url)
      .set('Content-Type', 'application/json')
      .set('Authorization', token)
      .set('latitude', currentObject.state.latitude)
      .set('longitude', currentObject.state.longitude)
      .send(JSON.stringify(currentObject.state.requestData))
      .end(function (error, response) {
        if (response)
          success(response.body, JSON.parse(response.statusCode), currentObject);
        else
          success(globals.errBody, globals.errStatusCode, currentObject);
      })

  },

  //Remove availability by date request
  deleteAvailabilityByDate: function (path, host, token, currentObject, success) {

    // Assign Complete url
    url = host + path;

    //Define Bearer authorization
    token = 'Bearer ' + token;

    //Set request
    globals.https.del(url)
      .set('Content-Type', 'application/json')
      .set('Authorization', token)
      .set('latitude', currentObject.state.latitude)
      .set('longitude', currentObject.state.longitude)
      .end(function (error, response) {
        if (response)
          success(response.body, JSON.parse(response.statusCode), currentObject);
        else
          success(globals.errBody, globals.errStatusCode, currentObject);
      })

  },

  //Update availability defaults request
  postAvailabilityDefaults: function (path, host, token, currentObject, success) {

    // Assign Complete url
    url = host + path;

    //Define Bearer authorization
    token = 'Bearer ' + token;

    //Set request
    globals.https.post(url)
      .set('Content-Type', 'application/json')
      .set('Authorization', token)
      .set('latitude', currentObject.state.latitude)
      .set('longitude', currentObject.state.longitude)
      .send(JSON.stringify(currentObject.state.requestData))
      .end(function (error, response) {
        if (response)
          success(response.body, JSON.parse(response.statusCode), currentObject);
        else
          success(globals.errBody, globals.errStatusCode, currentObject);
      })

  }

}
